@@ -1,4 +1,5 @@
 from django.db import models
+from django.conf import settings
 from prices import Price
 
 from . import forms
@@ -9,7 +10,7 @@ BaseField = models.SubfieldBase('BaseField', (models.DecimalField,), {})
 
 class PriceField(BaseField):
 
-    description = "A field which stores a price."
+    description = 'A field which stores a price.'
 
     def __init__(self, verbose_name=None, currency=None, **kwargs):
         self.currency = currency
@@ -54,14 +55,16 @@ class PriceField(BaseField):
         default = super(PriceField, self).get_default()
         return self.to_python(default)
 
-try:
+    def deconstruct(self):
+        name, path, args, kwargs = super(PriceField, self).deconstruct()
+        kwargs['currency'] = self.currency
+        return name, path, args, kwargs
+
+if 'south' in settings.INSTALLED_APPS:
     from south.modelsinspector import add_introspection_rules
-except ImportError:
-    pass
-else:
     rules = [
         ((PriceField,), [], {
             'currency': ('currency', {})
         })
     ]
-    add_introspection_rules(rules, ["^django_prices\.models"])
+    add_introspection_rules(rules, ['^django_prices\.models'])
